#[repr(u8)]pub enum Usb1VbusDetectClrVbusSourceSel {
VBUS_SOURCE_SEL_0 = 0,
VBUS_SOURCE_SEL_1 = 1,
VBUS_SOURCE_SEL_2 = 2,
_RESERVED_3 = 3,
}Variants
VBUS_SOURCE_SEL_0 = 0
Use the VBUS_VALID comparator results for signal reported to the USB controller (Default)
VBUS_SOURCE_SEL_1 = 1
Use the Session Valid comparator results for signal reported to the USB controller
VBUS_SOURCE_SEL_2 = 2
Use the Session Valid comparator results for signal reported to the USB controller
_RESERVED_3 = 3
Implementations